@@ -6,7 +6,7 @@ public class main {
     try {
 	System.loadLibrary("example");
     } catch (UnsatisfiedLinkError e) {
-      System.err.println("Cannot load the native code.\nMake sure your LD_LIBRARY_PATH contains \'.\'\n" + e);
+      System.err.println("Native code library failed to load. See the chapter on Dynamic Linking Problems in the SWIG Java documentation for help.\n" + e);
       System.exit(1);
     }
   }
