@@ -10,7 +10,7 @@
  * See the file LICENSE for information on usage and redistribution.
  * ----------------------------------------------------------------------------- */
 
-static char cvsroot[] = "$Header: /cvs/projects/SWIG/Source/DOH/Doh/base.c,v 1.43.4.1 2001/07/30 08:17:20 mkoeppe Exp $";
+static char cvsroot[] = "$Header: /cvs/projects/SWIG/Source/DOH/Doh/base.c,v 1.43.4.4 2001/12/03 15:39:33 beazley Exp $";
 
 #include "dohint.h"
 
@@ -243,12 +243,12 @@ DohSetattr(DOH *obj, const DOH *name, const DOH *value) {
  * DohDelattr()
  * ----------------------------------------------------------------------------- */
 
-void
+int
 DohDelattr(DOH *obj, const DOH *name) {
   DohBase *b = (DohBase *) obj;
   DohObjInfo *objinfo = dohtypes[b->type];
   if (objinfo->doh_hash && objinfo->doh_hash->doh_delattr) {
-    (objinfo->doh_hash->doh_delattr)(b,(DOH *) name);
+    return (objinfo->doh_hash->doh_delattr)(b,(DOH *) name);
   }
 }
 
@@ -672,6 +672,8 @@ int
 DohReplace(DOH *src, const DOH *token, const DOH *rep, int flags) {
   DohBase *b = (DohBase *) src;
   DohObjInfo *objinfo;
+  if (!token) return 0;
+  if (!rep) rep = "";
   if (DohIsString(src)) {
     objinfo = dohtypes[b->type];
     if (objinfo->doh_string->doh_replace) {
